==> 0.0.1.tar.gz: lib/attestr_flowx_plugin.dart <==

import 'package:eventify/eventify.dart';
import 'package:flutter/services.dart';

class AttestrFlowxPlugin {

  static const MethodChannel platform = MethodChannel('attestr_flowx_plugin');
  late Map<String, Object> result;
  late EventEmitter _eventEmitter;
  static const int FLOW_COMPLETE = 0;
  static const int FLOW_SKIP = 1;
  static const int FLOW_ERROR = 2;

  AttestrFlowxPlugin() {
    _eventEmitter = EventEmitter();
  }

  void _initiateSession(
      String handshakeID,
      String clientKey,
      String locale
      ) async {
    try {
      result = await platform.invokeMethod(
          'initiateSession',
          {
            "handshake_id": handshakeID,
            "client_key": clientKey,
            "locale": locale
          }
      );
      _handleResult(result);
    } on PlatformException catch (e) {
      print(e.toString());
    }
  }

  /// Handles checkout response from platform
  void _handleResult(Map<dynamic, dynamic> response) {
    switch (response['type']) {
      case FLOW_COMPLETE:
        _eventEmitter.emit(response['message']);
        break;
      case FLOW_SKIP:
        _eventEmitter.emit(response['message']);
        break;
      case FLOW_ERROR:
        _eventEmitter.emit(response['message']);
        break;
    }
  }

  // Registers event listeners
  void on(String event, Function handler) {
    EventCallback cb = (event, cont) {
      handler(event.eventData);
    };
    _eventEmitter.on(event, null, cb);
  }

  // Clears all event listeners
  void clear() {
    _eventEmitter.clear();
  }


}

==> 0.0.2.tar.gz: lib/attestr_flowx_plugin.dart <==

import 'package:eventify/eventify.dart';
import 'package:flutter/services.dart';

class AttestrFlowxPlugin {

  static const MethodChannel platform = MethodChannel('attestr_flowx_plugin');
  late Map<String, Object> result;
  late EventEmitter _eventEmitter;
  static const int FLOW_COMPLETE = 0;
  static const int FLOW_SKIP = 1;
  static const int FLOW_ERROR = 2;

  AttestrFlowxPlugin() {
    _eventEmitter = EventEmitter();
  }

  void initiateSession(
      String handshakeID,
      String clientKey,
      String locale
      ) async {
    try {
      result = await platform.invokeMethod(
          'initiateSession',
          {
            "handshake_id": handshakeID,
            "client_key": clientKey,
            "locale": locale
          }
      );
      _handleResult(result);
    } on PlatformException catch (e) {
      print(e.toString());
    }
  }

  /// Handles checkout response from platform
  void _handleResult(Map<dynamic, dynamic> response) {
    switch (response['type']) {
      case FLOW_COMPLETE:
        _eventEmitter.emit(response['message']);
        break;
      case FLOW_SKIP:
        _eventEmitter.emit(response['message']);
        break;
      case FLOW_ERROR:
        _eventEmitter.emit(response['message']);
        break;
    }
  }

  // Registers event listeners
  void on(String event, Function handler) {
    EventCallback cb = (event, cont) {
      handler(event.eventData);
    };
    _eventEmitter.on(event, null, cb);
  }

  // Clears all event listeners
  void clear() {
    _eventEmitter.clear();
  }


}
